==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/bullets.h <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void centerOnUnit(Unit *unit);
extern void addBulletParticle(Bullet *bullet);
extern void drawBoundingBox(Entity *entity);
extern void setStatusIndicator();
extern void doLineOfSight(Unit *unit);
extern void addBulletHitParticles(Bullet *bullet);
extern void addBloodParticles(Bullet *bullet);
extern void aiReactToShot(Unit *unit, Unit *bulletOwner);
extern void aiReactToSound(float x, float y, float z);
extern void addExplosionEffect(float x, float y, float z, int size, int life);
extern void drawSimpleModel(SimpleModel *model);
extern void addShieldHitParticles(Vector position);
extern void addShieldDestroyedParticles(Unit *unit);
extern void doExplosion(Vector position, int size, Entity *owner);
extern void addSparkParticle(Bullet *bullet);
extern bool withinViewableRange(Vector position, float size);
extern void addBubbleParticle(Vector position);
extern void throwUnit(Unit *unit, Vector velocity);
extern void addTrailParticle(Vector position, float size, GLColor color);
extern void moveEntity(Entity *entity);

extern Audio *audio;
extern BoundingBoxManager *bbManager;
extern BSP *bsp;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern ModelManager *modelManager;
extern TextureManager *textureManager;
extern Trace *tracer;
extern Unit *player;

extern Entity *self;

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/bullets.h <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void centerOnUnit(Unit *unit);
extern void addBulletParticle(Bullet *bullet);
extern void drawBoundingBox(Entity *entity);
extern void setStatusIndicator();
extern void doLineOfSight(Unit *unit);
extern void addBulletHitParticles(Bullet *bullet);
extern void addBloodParticles(Bullet *bullet);
extern void aiReactToShot(Unit *unit, Unit *bulletOwner);
extern void aiReactToSound(float x, float y, float z);
extern void addExplosionEffect(float x, float y, float z, int size, int life);
extern void drawSimpleModel(SimpleModel *model);
extern void addShieldHitParticles(Vector position);
extern void addShieldDestroyedParticles(Unit *unit);
extern void doExplosion(Vector position, int size, Entity *owner);
extern void addSparkParticle(Bullet *bullet);
extern bool withinViewableRange(Vector position, float size);
extern void addBubbleParticle(Vector position);
extern void throwUnit(Unit *unit, Vector velocity);
extern void addTrailParticle(Bullet *bullet);
extern void moveEntity(Entity *entity);
extern bool withinViewableRange(Entity *entity);
extern void generalUnitFrozen();
extern void addBlob(Properties *props);

extern Audio *audio;
extern BoundingBoxManager *bbManager;
extern BSP *bsp;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern ModelManager *modelManager;
extern TextureManager *textureManager;
extern Trace *tracer;
extern Unit *player;

extern Entity *self;
